@@ -33,11 +33,11 @@
 namespace Plasma
 {
 
-const char *ThemePrivate::defaultTheme = "default";
-const char *ThemePrivate::themeRcFile = "plasmarc";
+const char ThemePrivate::defaultTheme[] = "default";
+const char ThemePrivate::themeRcFile[] = "plasmarc";
 // the system colors theme is used to cache unthemed svgs with colorization needs
 // these svgs do not follow the theme's colors, but rather the system colors
-const char *ThemePrivate::systemColorsTheme = "internal-system-colors";
+const char ThemePrivate::systemColorsTheme[] = "internal-system-colors";
 #if HAVE_X11
 EffectWatcher *ThemePrivate::s_blurEffectWatcher = 0;
 #endif
@@ -66,7 +66,10 @@ ThemePrivate::ThemePrivate(QObject *parent)
       useGlobal(true),
       hasWallpapers(false),
       fixedName(false),
-      backgroundContrastEnabled(true)
+      backgroundContrastEnabled(true),
+      apiMajor(1),
+      apiMinor(0),
+      apiRevision(0)
 {
     ThemeConfig config;
     cacheTheme = config.cacheTheme();
@@ -112,7 +115,8 @@ ThemePrivate::ThemePrivate(QObject *parent)
 
 ThemePrivate::~ThemePrivate()
 {
-    if (FrameSvgPrivate::s_sharedFrames.contains(this)) { 
+    saveSvgElementsCache();
+    if (FrameSvgPrivate::s_sharedFrames.contains(this)) {
         foreach (FrameData *data, FrameSvgPrivate::s_sharedFrames[this].values()) {
             delete data;
         }
@@ -532,6 +536,13 @@ QColor ThemePrivate::color(Theme::ColorRole role, Theme::ColorGroup group) const
 {
     const KColorScheme *scheme = 0;
 
+    //Before 5.0 Plasma theme really only used Normal and Button
+    //many old themes are built on this assumption and will break
+    //otherwise
+    if (apiMajor < 5 && group != Theme::NormalColorGroup) {
+        group = Theme::ButtonColorGroup;
+    }
+
     switch (group) {
     case Theme::ButtonColorGroup: {
         scheme = &buttonColorScheme;
@@ -623,7 +634,7 @@ QColor ThemePrivate::color(Theme::ColorRole role, Theme::ColorGroup group) const
         break;
     }
     }
-    
+
 
 
     switch (role) {
@@ -748,13 +759,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
 
     if (colorsFile.isEmpty()) {
         colors = 0;
-        if (qApp) {
-            qApp->installEventFilter(this);
-        }
     } else {
-        if (qApp) {
-            qApp->removeEventFilter(this);
-        }
         colors = KSharedConfig::openConfig(colorsFile);
     }
 
@@ -796,6 +801,26 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
             KConfig metadata(metadataPath);
             processWallpaperSettings(&metadata);
         }
+
+        //Check for what Plasma version the theme has been done
+        //There are some behavioral differences between KDE4 Plasma and Plasma 5
+        cg = KConfigGroup(&metadata, "Desktop Entry");
+        const QString apiVersion = cg.readEntry("X-Plasma-API", QString());
+        apiMajor = 1;
+        apiMinor = 0;
+        apiRevision = 0;
+        if (!apiVersion.isEmpty()) {
+            QStringList parts = apiVersion.split('.');
+            if (!parts.isEmpty()) {
+                apiMajor = parts.value(0).toInt();
+            }
+            if (parts.count() > 1) {
+                apiMinor = parts.value(1).toInt();
+            }
+            if (parts.count() > 2) {
+                apiRevision = parts.value(2).toInt();
+            }
+        }
     }
 
     if (realTheme && isDefault && writeSettings) {
